"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListSharedReportGroups = void 0;
const CodeBuild_1 = require("../CodeBuild");
const CodeBuildClient_1 = require("../CodeBuildClient");
const ListSharedReportGroupsCommand_1 = require("../commands/ListSharedReportGroupsCommand");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListSharedReportGroupsCommand_1.ListSharedReportGroupsCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listSharedReportGroups(input, ...args);
};
async function* paginateListSharedReportGroups(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.nextToken = token;
        input["maxResults"] = config.pageSize;
        if (config.client instanceof CodeBuild_1.CodeBuild) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof CodeBuildClient_1.CodeBuildClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected CodeBuild | CodeBuildClient");
        }
        yield page;
        token = page.nextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListSharedReportGroups = paginateListSharedReportGroups;
