"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListActionTypes = void 0;
const CodePipeline_1 = require("../CodePipeline");
const CodePipelineClient_1 = require("../CodePipelineClient");
const ListActionTypesCommand_1 = require("../commands/ListActionTypesCommand");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListActionTypesCommand_1.ListActionTypesCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listActionTypes(input, ...args);
};
async function* paginateListActionTypes(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.nextToken = token;
        if (config.client instanceof CodePipeline_1.CodePipeline) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof CodePipelineClient_1.CodePipelineClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected CodePipeline | CodePipelineClient");
        }
        yield page;
        token = page.nextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListActionTypes = paginateListActionTypes;
